import requests
import json

class GleenAI:
    def __init__(self, api_key=None):
        self.api_key = api_key

    def set_api_key(self, key):
        self.api_key = key

    def send_message(self, query_text, thread_id=None, stream=False, functions=[], id=None, **kwargs):
        if not self.api_key:
            raise ValueError("Please set the API key first.")

        url = 'https://api.gleen.ai/api/v1/send_message'

        headers = {
            'Authorization': f'Bearer {self.api_key}',
            'Content-Type': 'application/json'
        }

        data = {
            "query_text": query_text,
            "thread_id": thread_id,
            "stream": stream,
            "locale": "en",
            "functions": functions
        }

        response = requests.post(url, headers=headers, data=json.dumps(data))
        return response.json()




from .api import GleenAI

_default_client = GleenAI()

def set_api_key(key):
    _default_client.set_api_key(key)

def send_message(*args, **kwargs):
    return _default_client.send_message(*args, **kwargs)




# setup.py

from setuptools import setup, find_packages

setup(
    name="gleenai",
    version="1.0.0",
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    author="Nagendra Kumar",
    author_email="nagendra@helix3.io",
    description="Python wrapper for GleenAI API.",
    license="MIT",
    keywords="gleenai api wrapper",
)

